import numpy as np
import base64

# noinspection SpellCheckingInspection
font_data = '''AAAAAPD//w/w//8P8A//AADwAAAA/w8AAPAAAAAAAAD/////AAAAAP////8AAP//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'''

SIZE = 32


def load_font():
    data = base64.b64decode(''.join(font_data.split('\n')))
    image = np.ndarray((256, 1024), dtype=np.uint8)
    image.fill(0)
    index = 0
    for i in range(image.shape[0]):
        for j in range(image.shape[1]):
            k = j & 7
            if data[index] & (1 << k) != 0:
                image[i, j] = 255
            if k == 7:
                index += 1
    return image


def show():
    import cv2
    cv2.imshow('vis', load_font())
    cv2.waitKey()


if __name__ == '__main__':
    show()
